from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RefLevelCls:
	"""RefLevel commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("refLevel", core, parent)

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	def set(self, scale: float, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:RLEVel \n
		Snippet: driver.display.window.subwindow.trace.y.scale.refLevel.set(scale = 1.0, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command defines the reference level (for all traces in all windows) . With a reference level offset ≠ 0, the value
		range of the reference level is modified by the offset. \n
			:param scale: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(scale)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:RLEVel {param}')

	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:RLEVel \n
		Snippet: value: float = driver.display.window.subwindow.trace.y.scale.refLevel.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command defines the reference level (for all traces in all windows) . With a reference level offset ≠ 0, the value
		range of the reference level is modified by the offset. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: scale: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:RLEVel?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'RefLevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RefLevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IvalCls:
	"""Ival commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ival", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Int_Start: int: Analysis start = Capture offset time Unit: s
			- Int_Stop: int: Analysis end = capture offset + capture time Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_int('Int_Start'),
			ArgStruct.scalar_int('Int_Stop')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Int_Start: int = None
			self.Int_Stop: int = None

	def get(self, window=repcap.Window.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:MSRA:WINDow:IVAL \n
		Snippet: value: GetStruct = driver.applications.k70Vsa.calculate.msra.window.ival.get(window = repcap.Window.Default) \n
		Returns the current analysis interval for applications in MSRA operating mode. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:MSRA:WINDow:IVAL?', self.__class__.GetStruct())



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DerrorCls:
	"""Derror commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("derror", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:FSK:DERRor \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.fsk.derror.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the frequency error of FSK modulated signals. \n
			:param result_type: none RMS frequency error of display points of current sweep AVG Average of frequency errors over several sweeps PAVG Average of maximum frequency errors over several sweeps PCTL 95% percentile of frequency error over several sweeps PEAK Maximum frequency error over all symbols of current sweep PPCT 95% percentile of maximum frequency errors over several sweeps PSD Standard deviation of maximum frequency errors over several sweeps RPE Maximum value of frequency error over several sweeps SDEV Standard deviation of frequency errors over several sweeps TPE Maximum frequency error over all display points over several sweeps
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:FSK:DERRor? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FplanCls:
	"""Fplan commands group definition. 13 total commands, 3 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fplan", core, parent)

	@property
	def predicted(self):
		"""predicted commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_predicted'):
			from .Predicted import PredictedCls
			self._predicted = PredictedCls(self._core, self._cmd_group)
		return self._predicted

	@property
	def transfer(self):
		"""transfer commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transfer'):
			from .Transfer import TransferCls
			self._transfer = TransferCls(self._core, self._cmd_group)
		return self._transfer

	@property
	def component(self):
		"""component commands group. 7 Sub-classes, 1 commands."""
		if not hasattr(self, '_component'):
			from .Component import ComponentCls
			self._component = ComponentCls(self._core, self._cmd_group)
		return self._component

	def save(self, filename: str) -> None:
		"""SCPI: [SENSe]:FPLan:SAVE \n
		Snippet: driver.applications.k50Spurious.sense.fplan.save(filename = '1') \n
		Saves the current frequency plan configuration to a user-defined .csv file for later use. The result is a comma-separated
		list of values with the following syntax for each row of the frequency plan: <Num>,<Comp>,<InFreq1>,<MaxHarm1>,<InFreq2>,
		<Fact>,<MaxHarm2>,<Ident2>,<BandCtr>,<BandSpn> \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:FPLan:SAVE {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SENSe]:FPLan:LOAD \n
		Snippet: driver.applications.k50Spurious.sense.fplan.load(filename = '1') \n
		Loads a stored frequency plan configuration from a .csv file. \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:FPLan:LOAD {param}')

	def clone(self) -> 'FplanCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FplanCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpdateCls:
	"""Update commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("update", core, parent)

	def set(self, directory: str) -> None:
		"""SCPI: SYSTem:FIRMware:UPDate \n
		Snippet: driver.system.firmware.update.set(directory = '1') \n
		This command starts a firmware update using the *.msi files in the selected directory. The default path is D:/FW_UPDATE.
		The path is changed via the method RsFswp.MassMemory.Comment.set command. To store the update files the MMEMory:DATA
		command is used. Only user accounts with administrator rights can perform a firmware update. \n
			:param directory: No help available
		"""
		param = Conversions.value_to_quoted_str(directory)
		self._core.io.write(f'SYSTem:FIRMware:UPDate {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:FIRMware:UPDate \n
		Snippet: value: str = driver.system.firmware.update.get() \n
		This command starts a firmware update using the *.msi files in the selected directory. The default path is D:/FW_UPDATE.
		The path is changed via the method RsFswp.MassMemory.Comment.set command. To store the update files the MMEMory:DATA
		command is used. Only user accounts with administrator rights can perform a firmware update. \n
			:return: directory: No help available"""
		response = self._core.io.query_str(f'SYSTem:FIRMware:UPDate?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	@property
	def factor(self):
		"""factor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_factor'):
			from .Factor import FactorCls
			self._factor = FactorCls(self._core, self._cmd_group)
		return self._factor

	def set(self, coupling_type: enums.FrequencyCouplingLinkA) -> None:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK \n
		Snippet: driver.sense.frequency.center.step.link.set(coupling_type = enums.FrequencyCouplingLinkA.OFF) \n
		This command selects the frequency step size mode. \n
			:param coupling_type: The step size is either a function of the span (x % of the span) or an absolute value. OFF Step size is a custom percentage of the span or an absolute custom value in Hz. You can define a percentage with [SENSe:]FREQuency:CENTer:STEP:LINK:FACTor. You can define a custom value with [SENSe:]FREQuency:CENTer:STEP. SPAN Step size is 10 % of the span.
		"""
		param = Conversions.enum_scalar_to_str(coupling_type, enums.FrequencyCouplingLinkA)
		self._core.io.write(f'SENSe:FREQuency:CENTer:STEP:LINK {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FrequencyCouplingLinkA:
		"""SCPI: [SENSe]:FREQuency:CENTer:STEP:LINK \n
		Snippet: value: enums.FrequencyCouplingLinkA = driver.sense.frequency.center.step.link.get() \n
		This command selects the frequency step size mode. \n
			:return: coupling_type: No help available"""
		response = self._core.io.query_str(f'SENSe:FREQuency:CENTer:STEP:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.FrequencyCouplingLinkA)

	def clone(self) -> 'LinkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LinkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class K40_PhaseNoiseCls:
	"""K40_PhaseNoise commands group definition. 37 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("k40_PhaseNoise", core, parent)

	@property
	def layout(self):
		"""layout commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_layout'):
			from .Layout import LayoutCls
			self._layout = LayoutCls(self._core, self._cmd_group)
		return self._layout

	@property
	def calculate(self):
		"""calculate commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_calculate'):
			from .Calculate import CalculateCls
			self._calculate = CalculateCls(self._core, self._cmd_group)
		return self._calculate

	@property
	def fetch(self):
		"""fetch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fetch'):
			from .Fetch import FetchCls
			self._fetch = FetchCls(self._core, self._cmd_group)
		return self._fetch

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def sense(self):
		"""sense commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sense'):
			from .Sense import SenseCls
			self._sense = SenseCls(self._core, self._cmd_group)
		return self._sense

	@property
	def display(self):
		"""display commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_display'):
			from .Display import DisplayCls
			self._display = DisplayCls(self._core, self._cmd_group)
		return self._display

	def clone(self) -> 'K40_PhaseNoiseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = K40_PhaseNoiseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def set(self, time: str) -> None:
		"""SCPI: CALibration:DUE:TIME \n
		Snippet: driver.calibration.due.time.set(time = '1') \n
		Defines the time at which a self-alignment is scheduled for the days specified by method RsFswp.Calibration.Due.Days.set,
		if method RsFswp.Calibration.Due.Schedule.set ON. \n
			:param time: string with format 'hh:mm' (24 hours)
		"""
		param = Conversions.value_to_quoted_str(time)
		self._core.io.write(f'CALibration:DUE:TIME {param}')

	def get(self) -> str:
		"""SCPI: CALibration:DUE:TIME \n
		Snippet: value: str = driver.calibration.due.time.get() \n
		Defines the time at which a self-alignment is scheduled for the days specified by method RsFswp.Calibration.Due.Days.set,
		if method RsFswp.Calibration.Due.Schedule.set ON. \n
			:return: time: string with format 'hh:mm' (24 hours)"""
		response = self._core.io.query_str(f'CALibration:DUE:TIME?')
		return trim_str_response(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WindowCls:
	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	def get(self) -> List[str]:
		"""SCPI: LAYout:CATalog[:WINDow] \n
		Snippet: value: List[str] = driver.applications.k40PhaseNoise.layout.catalog.window.get() \n
		This command queries the name and index of all active windows in the active channel from top left to bottom right.
		The result is a comma-separated list of values for each window, with the syntax: <WindowName_1>,<WindowIndex_1>..
		<WindowName_n>,<WindowIndex_n> \n
			:return: result: No help available"""
		response = self._core.io.query_str_with_opc(f'LAYout:CATalog:WINDow?')
		return Conversions.str_to_str_list(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NewCls:
	"""New commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("new", core, parent)

	def set(self, channel_type: enums.ChannelType, channel_name: str) -> None:
		"""SCPI: INSTrument:CREate[:NEW] \n
		Snippet: driver.instrument.create.new.set(channel_type = enums.ChannelType.IqAnalyzer=IQ, channel_name = '1') \n
		This command adds a measurement channel. You can configure up to 10 measurement channels at the same time (depending on
		available memory) .
			INTRO_CMD_HELP: See also \n
			- method RsFswp.Instrument.Select.set
			- method RsFswp.Instrument.delete \n
			:param channel_type: (enum or string) Channel type of the new channel. For a list of available channel types, see method RsFswp.Instrument.ListPy.get_.
			:param channel_name: String containing the name of the channel. Note that you cannot assign an existing channel name to a new channel. If you do, an error occurs.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('channel_type', channel_type, DataType.EnumExt, enums.ChannelType), ArgSingle('channel_name', channel_name, DataType.String))
		self._core.io.write_with_opc(f'INSTrument:CREate:NEW {param}'.rstrip())
		self._core.io.write('INIT:CONT OFF')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MemoryCls:
	"""Memory commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("memory", core, parent)

	def get(self, points_offset: int, points_count: int) -> List[float]:
		"""SCPI: TRACe:IQ:DATA:MEMory \n
		Snippet: value: List[float] = driver.trace.iq.data.memory.get(points_offset = 1, points_count = 1) \n
		This command queries the I/Q data currently stored in the capture buffer of the R&S FSWP. By default, the command returns
		all I/Q data in the memory. You can, however, narrow down the amount of data that the command returns using the optional
		parameters. If no parameters are specified with the command, the entire trace data is retrieved. In this case, the
		command returns the same results as method RsFswp.Trace.Iq.Data.get_. (Note, however, that the method RsFswp.Trace.Iq.
		Data.get_ command initiates a new measurement before returning the captured values, rather than returning the existing
		data in the memory.) The command returns a comma-separated list of the measured values in floating point format
		(comma-separated values = CSV) . The number of values returned is 2 * the number of complex samples. The total number of
		complex samples is displayed in the channel bar in manual operation and can be calculated as: <SampleRate> *
		<CaptureTime> (See TRACe:IQ:SET, method RsFswp.Applications.IqAnalyzer.Trace.Iq.SymbolRate.set and [SENSe:]SWEep:TIME) \n
			:param points_offset: No help available
			:param points_count: No help available
			:return: iq_data: Measured value pair (I,Q) for each sample that has been recorded. By default, the first half of the list contains the I values, the second half the Q values. The order can be configured using method RsFswp.Applications.IqAnalyzer.Trace.Iq.Data.FormatPy.set. The data format of the individual values depends on method RsFswp.FormatPy.Data.set. Unit: V"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('points_offset', points_offset, DataType.Integer), ArgSingle('points_count', points_count, DataType.Integer))
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe:IQ:DATA:MEMory? {param}'.rstrip())
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RestoreCls:
	"""Restore commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("restore", core, parent)

	def set(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:RESTore \n
		Snippet: driver.calculate.limit.espectrum.restore.set(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:RESTore')

	def set_with_opc(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:RESTore \n
		Snippet: driver.calculate.limit.espectrum.restore.set_with_opc(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:RESTore', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.TriggerSourceL) -> None:
		"""SCPI: TRIGger[:SEQuence]:SOURce \n
		Snippet: driver.applications.k50Spurious.trigger.sequence.source.set(source = enums.TriggerSourceL.EXT2) \n
		This command selects the trigger source. Note on external triggers: If a measurement is configured to wait for an
		external trigger signal in a remote control program, remote control is blocked until the trigger is received and the
		program can continue. Make sure that this situation is avoided in your remote control programs. \n
			:param source: IMMediate Free Run EXT | EXT2 Trigger signal from one of the 'Trigger Input/Output' connectors. Note: Connector must be configured for 'Input'.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.TriggerSourceL)
		self._core.io.write(f'TRIGger:SEQuence:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TriggerSourceL:
		"""SCPI: TRIGger[:SEQuence]:SOURce \n
		Snippet: value: enums.TriggerSourceL = driver.applications.k50Spurious.trigger.sequence.source.get() \n
		This command selects the trigger source. Note on external triggers: If a measurement is configured to wait for an
		external trigger signal in a remote control program, remote control is blocked until the trigger is received and the
		program can continue. Make sure that this situation is avoided in your remote control programs. \n
			:return: source: IMMediate Free Run EXT | EXT2 Trigger signal from one of the 'Trigger Input/Output' connectors. Note: Connector must be configured for 'Input'."""
		response = self._core.io.query_str(f'TRIGger:SEQuence:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSourceL)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.Utilities import trim_str_response
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WindowCls:
	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	def get(self, window_name: str, direction: enums.WindowDirection, window_type: enums.WindowTypeK60) -> str:
		"""SCPI: LAYout:ADD[:WINDow] \n
		Snippet: value: str = driver.applications.k60Transient.layout.add.window.get(window_name = '1', direction = enums.WindowDirection.ABOVe, window_type = enums.WindowTypeK60.ChirpRateTimeDomain=CRTime) \n
		This command adds a window to the display in the active channel. This command is always used as a query so that you
		immediately obtain the name of the new window as a result. To replace an existing window, use the method RsFswp.Layout.
		Replace.Window.set command. \n
			:param window_name: String containing the name of the existing window the new window is inserted next to. By default, the name of a window is the same as its index. To determine the name and index of all active windows, use the method RsFswp.Layout.Catalog.Window.get_ query.
			:param direction: LEFT | RIGHt | ABOVe | BELow Direction the new window is added relative to the existing window.
			:param window_type: (enum or string) text value Type of result display (evaluation method) you want to add. See the table below for available parameter values.
			:return: new_window_name: When adding a new window, the command returns its name (by default the same as its number) as a result."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('window_name', window_name, DataType.String), ArgSingle('direction', direction, DataType.Enum, enums.WindowDirection), ArgSingle('window_type', window_type, DataType.EnumExt, enums.WindowTypeK60))
		response = self._core.io.query_str_with_opc(f'LAYout:ADD:WINDow? {param}'.rstrip())
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, arg_0: bool, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:ROFFset[:STATe] \n
		Snippet: driver.applications.k50Spurious.sense.pmeter.roffset.state.set(arg_0 = False, powerMeter = repcap.PowerMeter.Default) \n
		This command includes or excludes the reference level offset of the analyzer for power sensor measurements. \n
			:param arg_0: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.bool_to_str(arg_0)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:ROFFset:STATe {param}')

	def get(self, powerMeter=repcap.PowerMeter.Default) -> bool:
		"""SCPI: [SENSe]:PMETer<p>:ROFFset[:STATe] \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.pmeter.roffset.state.get(powerMeter = repcap.PowerMeter.Default) \n
		This command includes or excludes the reference level offset of the analyzer for power sensor measurements. \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: arg_0: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:ROFFset:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	def get(self, meas_type: enums.AdemMeasType, window=repcap.Window.Default, marker=repcap.Marker.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:ADEMod:AM[:RESult<t>]:RELative \n
		Snippet: value: float = driver.calculate.marker.function.ademod.am.result.relative.get(meas_type = enums.AdemMeasType.MIDDle, window = repcap.Window.Default, marker = repcap.Marker.Default, trace = repcap.Trace.Default) \n
		This command queries the current relative value of the demodulated signal for the specified trace (as displayed in the
		'Result Summary' in manual operation) . Note that all windows with the same evaluation method have the same traces. The
		unit of the results depends on the method RsFswp.Configure.Ademod.Results.Unit.set setting. \n
			:param meas_type: PPEak Postive peak (+PK) MPEak | NPEak Negative peak (-PK) MIDDle Average of positive and negative peaks ±PK/2 RMS Root mean square value
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Result')
			:return: meas_type_result: No help available"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.AdemMeasType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:ADEMod:AM:RESult{trace_cmd_val}:RELative? {param}')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QuestionableCls:
	"""Questionable commands group definition. 100 total commands, 20 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("questionable", core, parent)

	@property
	def event(self):
		"""event commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_event'):
			from .Event import EventCls
			self._event = EventCls(self._core, self._cmd_group)
		return self._event

	@property
	def condition(self):
		"""condition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_condition'):
			from .Condition import ConditionCls
			self._condition = ConditionCls(self._core, self._cmd_group)
		return self._condition

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Enable import EnableCls
			self._enable = EnableCls(self._core, self._cmd_group)
		return self._enable

	@property
	def ptransition(self):
		"""ptransition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptransition'):
			from .Ptransition import PtransitionCls
			self._ptransition = PtransitionCls(self._core, self._cmd_group)
		return self._ptransition

	@property
	def ntransition(self):
		"""ntransition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntransition'):
			from .Ntransition import NtransitionCls
			self._ntransition = NtransitionCls(self._core, self._cmd_group)
		return self._ntransition

	@property
	def power(self):
		"""power commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def limit(self):
		"""limit commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def lmargin(self):
		"""lmargin commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_lmargin'):
			from .Lmargin import LmarginCls
			self._lmargin = LmarginCls(self._core, self._cmd_group)
		return self._lmargin

	@property
	def acpLimit(self):
		"""acpLimit commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_acpLimit'):
			from .AcpLimit import AcpLimitCls
			self._acpLimit = AcpLimitCls(self._core, self._cmd_group)
		return self._acpLimit

	@property
	def frequency(self):
		"""frequency commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def sync(self):
		"""sync commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	@property
	def diq(self):
		"""diq commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_diq'):
			from .Diq import DiqCls
			self._diq = DiqCls(self._core, self._cmd_group)
		return self._diq

	@property
	def time(self):
		"""time commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	@property
	def transducer(self):
		"""transducer commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_transducer'):
			from .Transducer import TransducerCls
			self._transducer = TransducerCls(self._core, self._cmd_group)
		return self._transducer

	@property
	def temperature(self):
		"""temperature commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_temperature'):
			from .Temperature import TemperatureCls
			self._temperature = TemperatureCls(self._core, self._cmd_group)
		return self._temperature

	@property
	def pnoise(self):
		"""pnoise commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_pnoise'):
			from .Pnoise import PnoiseCls
			self._pnoise = PnoiseCls(self._core, self._cmd_group)
		return self._pnoise

	@property
	def correction(self):
		"""correction commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def extended(self):
		"""extended commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_extended'):
			from .Extended import ExtendedCls
			self._extended = ExtendedCls(self._core, self._cmd_group)
		return self._extended

	@property
	def calibration(self):
		"""calibration commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def integrity(self):
		"""integrity commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_integrity'):
			from .Integrity import IntegrityCls
			self._integrity = IntegrityCls(self._core, self._cmd_group)
		return self._integrity

	def clone(self) -> 'QuestionableCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = QuestionableCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuationCls:
	"""Attenuation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuation", core, parent)

	def set(self, attenuation: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:ATTenuation \n
		Snippet: driver.applications.k30NoiseFigure.inputPy.attenuation.set(attenuation = 1.0, inputIx = repcap.InputIx.Default) \n
		This command defines the total attenuation for RF input. If you set the attenuation manually, it is no longer coupled to
		the reference level, but the reference level is coupled to the attenuation. Thus, if the current reference level is not
		compatible with an attenuation that has been set manually, the command also adjusts the reference level. \n
			:param attenuation: Range: see data sheet , Unit: DB
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:ATTenuation {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:ATTenuation \n
		Snippet: value: float = driver.applications.k30NoiseFigure.inputPy.attenuation.get(inputIx = repcap.InputIx.Default) \n
		This command defines the total attenuation for RF input. If you set the attenuation manually, it is no longer coupled to
		the reference level, but the reference level is coupled to the attenuation. Thus, if the current reference level is not
		compatible with an attenuation that has been set manually, the command also adjusts the reference level. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: attenuation: Range: see data sheet , Unit: DB"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:ATTenuation?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RemoveCls:
	"""Remove commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("remove", core, parent)

	def set(self, pattern: enums.SelectAll) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:PATTern:REMove \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.pattern.remove.set(pattern = enums.SelectAll.ALL) \n
		This command deletes one or all patterns from the current standard. \n
			:param pattern: (enum or string) No help available
		"""
		param = Conversions.enum_ext_scalar_to_str(pattern, enums.SelectAll)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:PATTern:REMove {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, qam_format: enums.QamFormat) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:QAM:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.qam.formatPy.set(qam_format = enums.QamFormat.DIFFerential) \n
		This command defines the specific demodulation order for QAM for the pattern. This command is only available if the
		additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param qam_format: NORMal | DIFFerential NORMal Demodulation order QAM is used. DIFFerential Demodulation order DQAM is used.
		"""
		param = Conversions.enum_scalar_to_str(qam_format, enums.QamFormat)
		self._core.io.write(f'SENSe:DDEMod:PATTern:QAM:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.QamFormat:
		"""SCPI: [SENSe]:DDEMod:PATTern:QAM:FORMat \n
		Snippet: value: enums.QamFormat = driver.applications.k70Vsa.sense.ddemod.pattern.qam.formatPy.get() \n
		This command defines the specific demodulation order for QAM for the pattern. This command is only available if the
		additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: qam_format: NORMal | DIFFerential NORMal Demodulation order QAM is used. DIFFerential Demodulation order DQAM is used."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:QAM:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.QamFormat)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PresetCls:
	"""Preset commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preset", core, parent)

	@property
	def channel(self):
		"""channel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import ChannelCls
			self._channel = ChannelCls(self._core, self._cmd_group)
		return self._channel

	@property
	def exec(self):
		"""exec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_exec'):
			from .Exec import ExecCls
			self._exec = ExecCls(self._core, self._cmd_group)
		return self._exec

	@property
	def compatible(self):
		"""compatible commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_compatible'):
			from .Compatible import CompatibleCls
			self._compatible = CompatibleCls(self._core, self._cmd_group)
		return self._compatible

	@property
	def inputPy(self):
		"""inputPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	def clone(self) -> 'PresetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PresetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentDirectoryCls:
	"""CurrentDirectory commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("currentDirectory", core, parent)

	def set(self, directory: str) -> None:
		"""SCPI: MMEMory:CDIRectory \n
		Snippet: driver.massMemory.currentDirectory.set(directory = '1') \n
		This command changes the current directory. \n
			:param directory: String containing the path to another directory. The path may be relative or absolute.
		"""
		param = Conversions.value_to_quoted_str(directory)
		self._core.io.write_with_opc(f'MMEMory:CDIRectory {param}')



from typing import List

from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.Types import DataType
from ..........Internal.StructBase import StructBase
from ..........Internal.ArgStruct import ArgStruct
from ..........Internal.ArgSingleList import ArgSingleList
from ..........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, frequency: List[float], thot: List[float], tcold: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:ENR[:MEASurement]:TABLe:TEMPerature[:DATA] \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.enr.measurement.table.temperature.data.set(frequency = [1.1, 2.2, 3.3], thot = [1.1, 2.2, 3.3], tcold = [1.1, 2.2, 3.3]) \n
		No command help available \n
			:param frequency: Unit: HZ
			:param thot: Unit: K
			:param tcold: Unit: K
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('frequency', frequency, DataType.FloatList, None), ArgSingle.as_open_list('thot', thot, DataType.FloatList, None), ArgSingle.as_open_list('tcold', tcold, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:ENR:MEASurement:TABLe:TEMPerature:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Frequency: List[float]: Unit: HZ
			- Thot: List[float]: Unit: K
			- Tcold: List[float]: Unit: K"""
		__meta_args_list = [
			ArgStruct('Frequency', DataType.FloatList, None, False, True, 1),
			ArgStruct('Thot', DataType.FloatList, None, False, True, 1),
			ArgStruct('Tcold', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: List[float] = None
			self.Thot: List[float] = None
			self.Tcold: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: [SENSe]:CORRection:ENR[:MEASurement]:TABLe:TEMPerature[:DATA] \n
		Snippet: value: DataStruct = driver.applications.k30NoiseFigure.sense.correction.enr.measurement.table.temperature.data.get() \n
		No command help available \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:ENR:MEASurement:TABLe:TEMPerature:DATA?', self.__class__.DataStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	@property
	def external(self):
		"""external commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	@property
	def ifPower(self):
		"""ifPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ifPower'):
			from .IfPower import IfPowerCls
			self._ifPower = IfPowerCls(self._core, self._cmd_group)
		return self._ifPower

	@property
	def rfPower(self):
		"""rfPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfPower'):
			from .RfPower import RfPowerCls
			self._rfPower = RfPowerCls(self._core, self._cmd_group)
		return self._rfPower

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandCls:
	"""Band commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("band", core, parent)

	def set(self, band: enums.BandB) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:BAND \n
		Snippet: driver.applications.k50Spurious.sense.correction.cvl.band.set(band = enums.BandB.D) \n
		This command defines the waveguide band for which the conversion loss table is to be used. This setting is checked
		against the current mixer setting before the table can be assigned to the range. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with
		option B21 (External Mixer) installed. \n
			:param band: (enum or string) K | KA | Q | U | V | E | W | F | D | G | Y | J | USER Standard waveguide band or user-defined band. For a definition of the frequency range for the pre-defined bands, see Table 'Frequency ranges for pre-defined bands') .
		"""
		param = Conversions.enum_ext_scalar_to_str(band, enums.BandB)
		self._core.io.write(f'SENSe:CORRection:CVL:BAND {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.BandB:
		"""SCPI: [SENSe]:CORRection:CVL:BAND \n
		Snippet: value: enums.BandB = driver.applications.k50Spurious.sense.correction.cvl.band.get() \n
		This command defines the waveguide band for which the conversion loss table is to be used. This setting is checked
		against the current mixer setting before the table can be assigned to the range. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with
		option B21 (External Mixer) installed. \n
			:return: band: (enum or string) K | KA | Q | U | V | E | W | F | D | G | Y | J | USER Standard waveguide band or user-defined band. For a definition of the frequency range for the pre-defined bands, see Table 'Frequency ranges for pre-defined bands') ."""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:BAND?')
		return Conversions.str_to_scalar_enum_ext(response, enums.BandB)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InputPyCls:
	"""InputPy commands group definition. 14 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("inputPy", core, parent)

	@property
	def emi(self):
		"""emi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_emi'):
			from .Emi import EmiCls
			self._emi = EmiCls(self._core, self._cmd_group)
		return self._emi

	@property
	def rf(self):
		"""rf commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rf'):
			from .Rf import RfCls
			self._rf = RfCls(self._core, self._cmd_group)
		return self._rf

	@property
	def mc(self):
		"""mc commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mc'):
			from .Mc import McCls
			self._mc = McCls(self._core, self._cmd_group)
		return self._mc

	@property
	def aiq(self):
		"""aiq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_aiq'):
			from .Aiq import AiqCls
			self._aiq = AiqCls(self._core, self._cmd_group)
		return self._aiq

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def pulsed(self):
		"""pulsed commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pulsed'):
			from .Pulsed import PulsedCls
			self._pulsed = PulsedCls(self._core, self._cmd_group)
		return self._pulsed

	@property
	def synthTwo(self):
		"""synthTwo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_synthTwo'):
			from .SynthTwo import SynthTwoCls
			self._synthTwo = SynthTwoCls(self._core, self._cmd_group)
		return self._synthTwo

	def clone(self) -> 'InputPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InputPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InputPyCls:
	"""InputPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("inputPy", core, parent)

	def set(self, default_input: enums.InputSelect) -> None:
		"""SCPI: SYSTem:PRESet:INPut \n
		Snippet: driver.system.preset.inputPy.set(default_input = enums.InputSelect.INPut1) \n
		No command help available \n
			:param default_input: No help available
		"""
		param = Conversions.enum_scalar_to_str(default_input, enums.InputSelect)
		self._core.io.write(f'SYSTem:PRESet:INPut {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InputSelect:
		"""SCPI: SYSTem:PRESet:INPut \n
		Snippet: value: enums.InputSelect = driver.system.preset.inputPy.get() \n
		No command help available \n
			:return: default_input: No help available"""
		response = self._core.io.query_str(f'SYSTem:PRESet:INPut?')
		return Conversions.str_to_scalar_enum(response, enums.InputSelect)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EventCls:
	"""Event commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("event", core, parent)

	def get(self) -> int:
		"""SCPI: STATus:OPERation[:EVENt] \n
		Snippet: value: int = driver.status.operation.event.get() \n
		These commands read out the EVENt section of the status register. At the same time, the commands delete the contents of
		the EVENt section. \n
			:return: register_value: No help available"""
		response = self._core.io.query_str(f'STATus:OPERation:EVENt?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, repetition_count: float) -> None:
		"""SCPI: TRACe:IQ:FILE:REPetition:COUNt \n
		Snippet: driver.trace.iq.file.repetition.count.set(repetition_count = 1.0) \n
		Determines how often the data stream is repeatedly copied in the I/Q data memory. If the available memory is not
		sufficient for the specified number of repetitions, the largest possible number of complete data streams is used. \n
			:param repetition_count: integer
		"""
		param = Conversions.decimal_value_to_str(repetition_count)
		self._core.io.write(f'TRACe:IQ:FILE:REPetition:COUNt {param}')

	def get(self) -> float:
		"""SCPI: TRACe:IQ:FILE:REPetition:COUNt \n
		Snippet: value: float = driver.trace.iq.file.repetition.count.get() \n
		Determines how often the data stream is repeatedly copied in the I/Q data memory. If the available memory is not
		sufficient for the specified number of repetitions, the largest possible number of complete data streams is used. \n
			:return: repetition_count: integer"""
		response = self._core.io.query_str(f'TRACe:IQ:FILE:REPetition:COUNt?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.GatedSourceK30) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:SOURce \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.source.set(source = enums.GatedSourceK30.EXT2) \n
		This command selects the signal source for gated measurements. If an IF power signal is used, the gate is opened as soon
		as a signal at > -20 dBm is detected within the IF path bandwidth (10 MHz) . For more information see 'Trigger Source'. \n
			:param source: EXTernal | EXT2 | EXT3 | IFPower | IQPower | VIDeo | RFPower | PSEN
		"""
		param = Conversions.enum_scalar_to_str(source, enums.GatedSourceK30)
		self._core.io.write(f'SENSe:SWEep:EGATe:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GatedSourceK30:
		"""SCPI: [SENSe]:SWEep:EGATe:SOURce \n
		Snippet: value: enums.GatedSourceK30 = driver.applications.k30NoiseFigure.sense.sweep.egate.source.get() \n
		This command selects the signal source for gated measurements. If an IF power signal is used, the gate is opened as soon
		as a signal at > -20 dBm is detected within the IF path bandwidth (10 MHz) . For more information see 'Trigger Source'. \n
			:return: source: EXTernal | EXT2 | EXT3 | IFPower | IQPower | VIDeo | RFPower | PSEN"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.GatedSourceK30)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NofCls:
	"""Nof commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nof", core, parent)

	def set(self, periods_count: int) -> None:
		"""SCPI: TRACe:IQ:EGATe:NOF \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.egate.nof.set(periods_count = 1) \n
		This command defines the number of gate periods after the trigger signal for gated measurements with the I/Q analyzer. \n
			:param periods_count: Range: 1 to 1023
		"""
		param = Conversions.decimal_value_to_str(periods_count)
		self._core.io.write(f'TRACe:IQ:EGATe:NOF {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:EGATe:NOF \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.egate.nof.get() \n
		This command defines the number of gate periods after the trigger signal for gated measurements with the I/Q analyzer. \n
			:return: periods_count: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:EGATe:NOF?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InterfaceCls:
	"""Interface commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interface", core, parent)

	def set(self, type_py: enums.GeneratorIntfType, generator=repcap.Generator.Default) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:INTerface \n
		Snippet: driver.system.communicate.rdevice.generator.interface.set(type_py = enums.GeneratorIntfType.GPIB, generator = repcap.Generator.Default) \n
		No command help available \n
			:param type_py: No help available
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GeneratorIntfType)
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:INTerface {param}')

	# noinspection PyTypeChecker
	def get(self, generator=repcap.Generator.Default) -> enums.GeneratorIntfType:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:INTerface \n
		Snippet: value: enums.GeneratorIntfType = driver.system.communicate.rdevice.generator.interface.get(generator = repcap.Generator.Default) \n
		No command help available \n
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
			:return: type_py: No help available"""
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:INTerface?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorIntfType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LbWidthCls:
	"""LbWidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lbWidth", core, parent)

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:ROSCillator:LBWidth \n
		Snippet: driver.sense.roscillator.lbWidth.set(bandwidth = 1.0) \n
		Defines the loop bandwidth, that is, the speed of internal synchronization with the reference frequency. The setting
		requires a compromise between performance and increasing phase noise. For a variable external reference frequency with a
		narrow tuning range (+/- 0.5 ppm) , the loop bandwidth is fixed to 0.1 Hz and cannot be changed. \n
			:param bandwidth: 0.1 Hz | 1 Hz | 3 Hz | 10 Hz | 30 Hz | 100 Hz | 300 Hz The possible values depend on the reference source and tuning range (see Table 'Available Reference Frequency Input') . Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:ROSCillator:LBWidth {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ROSCillator:LBWidth \n
		Snippet: value: float = driver.sense.roscillator.lbWidth.get() \n
		Defines the loop bandwidth, that is, the speed of internal synchronization with the reference frequency. The setting
		requires a compromise between performance and increasing phase noise. For a variable external reference frequency with a
		narrow tuning range (+/- 0.5 ppm) , the loop bandwidth is fixed to 0.1 Hz and cannot be changed. \n
			:return: bandwidth: 0.1 Hz | 1 Hz | 3 Hz | 10 Hz | 30 Hz | 100 Hz | 300 Hz The possible values depend on the reference source and tuning range (see Table 'Available Reference Frequency Input') . Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:ROSCillator:LBWidth?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SignalCls:
	"""Signal commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("signal", core, parent)

	def set(self, bias: enums.State) -> None:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: driver.applications.k50Spurious.sense.mixer.signal.set(bias = enums.State.ALL) \n
		No command help available \n
			:param bias: No help available
		"""
		param = Conversions.enum_scalar_to_str(bias, enums.State)
		self._core.io.write(f'SENSe:MIXer:SIGNal {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.State:
		"""SCPI: [SENSe]:MIXer:SIGNal \n
		Snippet: value: enums.State = driver.applications.k50Spurious.sense.mixer.signal.get() \n
		No command help available \n
			:return: bias: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:SIGNal?')
		return Conversions.str_to_scalar_enum(response, enums.State)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaximumCls:
	"""Maximum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maximum", core, parent)

	def set(self, freq_range: float) -> None:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:SPAN[:MAXimum] \n
		Snippet: driver.sense.ademod.spectrum.span.maximum.set(freq_range = 1.0) \n
		Sets the DBW to the specified value and the span (around the center frequency) of the RF data to be evaluated to its new
		maximum (the demodulation bandwidth) . \n
			:param freq_range: Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq_range)
		self._core.io.write(f'SENSe:ADEMod:SPECtrum:SPAN:MAXimum {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:SPECtrum:SPAN[:MAXimum] \n
		Snippet: value: float = driver.sense.ademod.spectrum.span.maximum.get() \n
		Sets the DBW to the specified value and the span (around the center frequency) of the RF data to be evaluated to its new
		maximum (the demodulation bandwidth) . \n
			:return: freq_range: Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:ADEMod:SPECtrum:SPAN:MAXimum?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.TraceModeE, trace=repcap.Trace.Default) -> None:
		"""SCPI: CONFigure:ADEMod:RESults:PM:DETector<det>:MODE \n
		Snippet: driver.configure.ademod.results.pm.detector.mode.set(mode = enums.TraceModeE.AVERage, trace = repcap.Trace.Default) \n
		Defines the mode with which the demodulation result is determined. \n
			:param mode: WRITe Overwrite mode: the detector value is overwritten by each sweep. This is the default setting. AVERage The average result is determined over all sweeps. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves each result only if the new value is greater than the previous one.
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.TraceModeE)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CONFigure:ADEMod:RESults:PM:DETector{trace_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, trace=repcap.Trace.Default) -> enums.TraceModeE:
		"""SCPI: CONFigure:ADEMod:RESults:PM:DETector<det>:MODE \n
		Snippet: value: enums.TraceModeE = driver.configure.ademod.results.pm.detector.mode.get(trace = repcap.Trace.Default) \n
		Defines the mode with which the demodulation result is determined. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
			:return: mode: WRITe Overwrite mode: the detector value is overwritten by each sweep. This is the default setting. AVERage The average result is determined over all sweeps. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves each result only if the new value is greater than the previous one."""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CONFigure:ADEMod:RESults:PM:DETector{trace_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TraceModeE)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuationCls:
	"""Attenuation commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuation", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, attenuation: float) -> None:
		"""SCPI: INPut:ATTenuation \n
		Snippet: driver.applications.k60Transient.inputPy.attenuation.set(attenuation = 1.0) \n
		This command defines the total attenuation for RF input. If you set the attenuation manually, it is no longer coupled to
		the reference level, but the reference level is coupled to the attenuation. Thus, if the current reference level is not
		compatible with an attenuation that has been set manually, the command also adjusts the reference level. \n
			:param attenuation: Range: see data sheet , Unit: DB
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'INPut:ATTenuation {param}')

	def get(self) -> float:
		"""SCPI: INPut:ATTenuation \n
		Snippet: value: float = driver.applications.k60Transient.inputPy.attenuation.get() \n
		This command defines the total attenuation for RF input. If you set the attenuation manually, it is no longer coupled to
		the reference level, but the reference level is coupled to the attenuation. Thus, if the current reference level is not
		compatible with an attenuation that has been set manually, the command also adjusts the reference level. \n
			:return: attenuation: Range: see data sheet , Unit: DB"""
		response = self._core.io.query_str(f'INPut:ATTenuation?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'AttenuationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AttenuationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnusedDrivesCls:
	"""UnusedDrives commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("unusedDrives", core, parent)

	def get(self) -> List[str]:
		"""SCPI: MMEMory:NETWork:UNUSeddrives \n
		Snippet: value: List[str] = driver.massMemory.network.unusedDrives.get() \n
		This command returns a list of unused network drives. \n
			:return: drives: List of network drives in alphabetically descending order, e.g. 'W:,V:,U:,...'"""
		response = self._core.io.query_str_with_opc(f'MMEMory:NETWork:UNUSeddrives?')
		return Conversions.str_to_str_list(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:LINes:ALL \n
		Snippet: driver.massMemory.select.item.lines.all.set(state = False) \n
		This command includes or excludes all limit lines (active and inactive) when storing or loading a configuration file.
		Depending on the used command, either the items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those
		from the currently selected channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:SELect:ITEM:LINes:ALL {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SequencerCls:
	"""Sequencer commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequencer", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:SEQuencer \n
		Snippet: driver.system.sequencer.set(state = False) \n
		This command turns the Sequencer on and off. The Sequencer must be active before any other Sequencer commands (INIT:SEQ...
		) are executed, otherwise an error occurs. For details on the Sequencer see 'The Sequencer Concept'.
		A detailed programming example is provided in 'Programming Example: Performing a Sequence of Measurements'. \n
			:param state: ON | OFF | 0 | 1 ON | 1 The Sequencer is activated and a sequential measurement is started immediately. OFF | 0 The Sequencer is deactivated. Any running sequential measurements are stopped. Further Sequencer commands (INIT:SEQ...) are not available.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:SEQuencer {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:SEQuencer \n
		Snippet: value: bool = driver.system.sequencer.get() \n
		This command turns the Sequencer on and off. The Sequencer must be active before any other Sequencer commands (INIT:SEQ...
		) are executed, otherwise an error occurs. For details on the Sequencer see 'The Sequencer Concept'.
		A detailed programming example is provided in 'Programming Example: Performing a Sequence of Measurements'. \n
			:return: state: ON | OFF | 0 | 1 ON | 1 The Sequencer is activated and a sequential measurement is started immediately. OFF | 0 The Sequencer is deactivated. Any running sequential measurements are stopped. Further Sequencer commands (INIT:SEQ...) are not available."""
		response = self._core.io.query_str(f'SYSTem:SEQuencer?')
		return Conversions.str_to_bool(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	def get(self, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>:IQ:SCAPture:TSTamp:TRIGger \n
		Snippet: value: List[float] = driver.trace.iq.scapture.tstamp.trigger.get(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: timestamps: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'TRACe{window_cmd_val}:IQ:SCAPture:TSTamp:TRIGger?')
		return response



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DenominatorCls:
	"""Denominator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("denominator", core, parent)

	def set(self, denominator: float) -> None:
		"""SCPI: SOURce:EXTernal:FREQuency[:FACTor]:DENominator \n
		Snippet: driver.applications.k30NoiseFigure.source.external.frequency.factor.denominator.set(denominator = 1.0) \n
		No command help available \n
			:param denominator: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(denominator)
		self._core.io.write(f'SOURce:EXTernal:FREQuency:FACTor:DENominator {param}')

	def get(self) -> float:
		"""SCPI: SOURce:EXTernal:FREQuency[:FACTor]:DENominator \n
		Snippet: value: float = driver.applications.k30NoiseFigure.source.external.frequency.factor.denominator.get() \n
		No command help available \n
			:return: denominator: Unit: HZ"""
		response = self._core.io.query_str(f'SOURce:EXTernal:FREQuency:FACTor:DENominator?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandCls:
	"""Band commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("band", core, parent)

	def set(self, band: enums.Band) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND \n
		Snippet: driver.sense.mixer.harmonic.band.set(band = enums.Band.A) \n
		This command selects the external mixer band. The query returns the currently selected band. This command is only
		available if the external mixer is active (see [SENSe:]MIXer<x>[:STATe]) . \n
			:param band: KA | Q | U | V | E | W | F | D | G | Y | J | USER Standard waveguide band or user-defined band.
		"""
		param = Conversions.enum_scalar_to_str(band, enums.Band)
		self._core.io.write(f'SENSe:MIXer:HARMonic:BAND {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.Band:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND \n
		Snippet: value: enums.Band = driver.sense.mixer.harmonic.band.get() \n
		This command selects the external mixer band. The query returns the currently selected band. This command is only
		available if the external mixer is active (see [SENSe:]MIXer<x>[:STATe]) . \n
			:return: band: KA | Q | U | V | E | W | F | D | G | Y | J | USER Standard waveguide band or user-defined band."""
		response = self._core.io.query_str(f'SENSe:MIXer:HARMonic:BAND?')
		return Conversions.str_to_scalar_enum(response, enums.Band)

	def preset(self) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND:PRESet \n
		Snippet: driver.sense.mixer.harmonic.band.preset() \n
		This command restores the preset frequency ranges for the selected standard waveguide band. Note:Changes to the band and
		mixer settings are maintained even after using the [PRESET] function. Use this command to restore the predefined band
		ranges. \n
		"""
		self._core.io.write(f'SENSe:MIXer:HARMonic:BAND:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:BAND:PRESet \n
		Snippet: driver.sense.mixer.harmonic.band.preset_with_opc() \n
		This command restores the preset frequency ranges for the selected standard waveguide band. Note:Changes to the band and
		mixer settings are maintained even after using the [PRESET] function. Use this command to restore the predefined band
		ranges. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:MIXer:HARMonic:BAND:PRESet', opc_timeout_ms)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StatisticCls:
	"""Statistic commands group definition. 19 total commands, 16 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("statistic", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def adroop(self):
		"""adroop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adroop'):
			from .Adroop import AdroopCls
			self._adroop = AdroopCls(self._core, self._cmd_group)
		return self._adroop

	@property
	def cfError(self):
		"""cfError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cfError'):
			from .CfError import CfErrorCls
			self._cfError = CfErrorCls(self._core, self._cmd_group)
		return self._cfError

	@property
	def evm(self):
		"""evm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_evm'):
			from .Evm import EvmCls
			self._evm = EvmCls(self._core, self._cmd_group)
		return self._evm

	@property
	def gimbalance(self):
		"""gimbalance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gimbalance'):
			from .Gimbalance import GimbalanceCls
			self._gimbalance = GimbalanceCls(self._core, self._cmd_group)
		return self._gimbalance

	@property
	def fdError(self):
		"""fdError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdError'):
			from .FdError import FdErrorCls
			self._fdError = FdErrorCls(self._core, self._cmd_group)
		return self._fdError

	@property
	def iqImbalance(self):
		"""iqImbalance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqImbalance'):
			from .IqImbalance import IqImbalanceCls
			self._iqImbalance = IqImbalanceCls(self._core, self._cmd_group)
		return self._iqImbalance

	@property
	def merror(self):
		"""merror commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_merror'):
			from .Merror import MerrorCls
			self._merror = MerrorCls(self._core, self._cmd_group)
		return self._merror

	@property
	def mpower(self):
		"""mpower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mpower'):
			from .Mpower import MpowerCls
			self._mpower = MpowerCls(self._core, self._cmd_group)
		return self._mpower

	@property
	def ooffset(self):
		"""ooffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ooffset'):
			from .Ooffset import OoffsetCls
			self._ooffset = OoffsetCls(self._core, self._cmd_group)
		return self._ooffset

	@property
	def perror(self):
		"""perror commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_perror'):
			from .Perror import PerrorCls
			self._perror = PerrorCls(self._core, self._cmd_group)
		return self._perror

	@property
	def qerror(self):
		"""qerror commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_qerror'):
			from .Qerror import QerrorCls
			self._qerror = QerrorCls(self._core, self._cmd_group)
		return self._qerror

	@property
	def rho(self):
		"""rho commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rho'):
			from .Rho import RhoCls
			self._rho = RhoCls(self._core, self._cmd_group)
		return self._rho

	@property
	def srError(self):
		"""srError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srError'):
			from .SrError import SrErrorCls
			self._srError = SrErrorCls(self._core, self._cmd_group)
		return self._srError

	@property
	def snr(self):
		"""snr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_snr'):
			from .Snr import SnrCls
			self._snr = SnrCls(self._core, self._cmd_group)
		return self._snr

	@property
	def fsk(self):
		"""fsk commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fsk'):
			from .Fsk import FskCls
			self._fsk = FskCls(self._core, self._cmd_group)
		return self._fsk

	def clone(self) -> 'StatisticCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StatisticCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RlengthCls:
	"""Rlength commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rlength", core, parent)

	def set(self, record_length: int) -> None:
		"""SCPI: TRACe:IQ:RLENgth \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.rlength.set(record_length = 1) \n
		This command sets the record length for the acquired I/Q data. Increasing the record length also increases the
		measurement time. Note: Alternatively, you can define the measurement time using the SENS:SWE:TIME command. \n
			:param record_length: Number of samples to record. See 'Sample rate and maximum usable I/Q bandwidth for RF input'.
		"""
		param = Conversions.decimal_value_to_str(record_length)
		self._core.io.write(f'TRACe:IQ:RLENgth {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:RLENgth \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.rlength.get() \n
		This command sets the record length for the acquired I/Q data. Increasing the record length also increases the
		measurement time. Note: Alternatively, you can define the measurement time using the SENS:SWE:TIME command. \n
			:return: record_length: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:RLENgth?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InternalCls:
	"""Internal commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("internal", core, parent)

	@property
	def completed(self):
		"""completed commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_completed'):
			from .Completed import CompletedCls
			self._completed = CompletedCls(self._core, self._cmd_group)
		return self._completed

	@property
	def command(self):
		"""command commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_command'):
			from .Command import CommandCls
			self._command = CommandCls(self._core, self._cmd_group)
		return self._command

	def clone(self) -> 'InternalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InternalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:DELete:IMMediate \n
		Snippet: driver.massMemory.delete.immediate.set(filename = '1') \n
		This command deletes a file. \n
			:param filename: String containing the path and file name of the file to delete. The path may be relative or absolute.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'MMEMory:DELete:IMMediate {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuationCls:
	"""Attenuation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuation", core, parent)

	def set(self, attenuation: float) -> None:
		"""SCPI: [SENSe]:DIRected:INPut:ATTenuation \n
		Snippet: driver.applications.k50Spurious.sense.directed.inputPy.attenuation.set(attenuation = 1.0) \n
		Defines the RF attenuation for the directed search measurement. \n
			:param attenuation: integer Range: 0 dB to 79 dB, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'SENSe:DIRected:INPut:ATTenuation {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DIRected:INPut:ATTenuation \n
		Snippet: value: float = driver.applications.k50Spurious.sense.directed.inputPy.attenuation.get() \n
		Defines the RF attenuation for the directed search measurement. \n
			:return: attenuation: integer Range: 0 dB to 79 dB, Unit: DB"""
		response = self._core.io.query_str(f'SENSe:DIRected:INPut:ATTenuation?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmCls:
	"""Pm commands group definition. 6 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pm", core, parent)

	@property
	def tdomain(self):
		"""tdomain commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdomain'):
			from .Tdomain import TdomainCls
			self._tdomain = TdomainCls(self._core, self._cmd_group)
		return self._tdomain

	@property
	def afSpectrum(self):
		"""afSpectrum commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_afSpectrum'):
			from .AfSpectrum import AfSpectrumCls
			self._afSpectrum = AfSpectrumCls(self._core, self._cmd_group)
		return self._afSpectrum

	@property
	def rpoint(self):
		"""rpoint commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rpoint'):
			from .Rpoint import RpointCls
			self._rpoint = RpointCls(self._core, self._cmd_group)
		return self._rpoint

	def clone(self) -> 'PmCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PmCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScaleCls:
	"""Scale commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scale", core, parent)

	def set(self, scale: bool) -> None:
		"""SCPI: HCOPy:PAGE:WINDow:SCALe \n
		Snippet: driver.hardCopy.page.window.scale.set(scale = False) \n
		This command determines the scaling of the windows in the printout for method RsFswp.HardCopy.Content.set. \n
			:param scale: 1 | 0 | ON | OFF 1 | ON Each window is scaled to fit the page size optimally, not regarding the aspect ratio of the original display. If more than one window is printed on one page (see method RsFswp.HardCopy.Page.Window.Count.set) , each window is printed in equal size. ('Size to fit') 0 | OFF Each window is printed as large as possible while maintaining the aspect ratio of the original display. ('Maintain aspect ratio')
		"""
		param = Conversions.bool_to_str(scale)
		self._core.io.write(f'HCOPy:PAGE:WINDow:SCALe {param}')

	def get(self) -> bool:
		"""SCPI: HCOPy:PAGE:WINDow:SCALe \n
		Snippet: value: bool = driver.hardCopy.page.window.scale.get() \n
		This command determines the scaling of the windows in the printout for method RsFswp.HardCopy.Content.set. \n
			:return: scale: 1 | 0 | ON | OFF 1 | ON Each window is scaled to fit the page size optimally, not regarding the aspect ratio of the original display. If more than one window is printed on one page (see method RsFswp.HardCopy.Page.Window.Count.set) , each window is printed in equal size. ('Size to fit') 0 | OFF Each window is printed as large as possible while maintaining the aspect ratio of the original display. ('Maintain aspect ratio')"""
		response = self._core.io.query_str(f'HCOPy:PAGE:WINDow:SCALe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PnLimitCls:
	"""PnLimit commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pnLimit", core, parent)

	@property
	def fail(self):
		"""fail commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fail'):
			from .Fail import FailCls
			self._fail = FailCls(self._core, self._cmd_group)
		return self._fail

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def fc(self):
		"""fc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fc'):
			from .Fc import FcCls
			self._fc = FcCls(self._core, self._cmd_group)
		return self._fc

	def clone(self) -> 'PnLimitCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PnLimitCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VersionCls:
	"""Version commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("version", core, parent)

	def set(self, snmp_version: enums.SnmpVersion) -> None:
		"""SCPI: SYSTem:COMMunicate:SNMP:VERSion \n
		Snippet: driver.system.communicate.snmp.version.set(snmp_version = enums.SnmpVersion.DEFault) \n
		Selects the SNMP version. \n
			:param snmp_version: OFF | V12 | V123 | V3 | DEFault OFF SNMP communication is off. V12 SNMP communication with SNMPv2 or lower. V123 SNMP communication with SNMPv2 and SNMPv3. V3 SNMP communication with SNMPv3.
		"""
		param = Conversions.enum_scalar_to_str(snmp_version, enums.SnmpVersion)
		self._core.io.write(f'SYSTem:COMMunicate:SNMP:VERSion {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SnmpVersion:
		"""SCPI: SYSTem:COMMunicate:SNMP:VERSion \n
		Snippet: value: enums.SnmpVersion = driver.system.communicate.snmp.version.get() \n
		Selects the SNMP version. \n
			:return: snmp_version: OFF | V12 | V123 | V3 | DEFault OFF SNMP communication is off. V12 SNMP communication with SNMPv2 or lower. V123 SNMP communication with SNMPv2 and SNMPv3. V3 SNMP communication with SNMPv3."""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:SNMP:VERSion?')
		return Conversions.str_to_scalar_enum(response, enums.SnmpVersion)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def set(self, position: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:X \n
		Snippet: driver.applications.k60Transient.calculate.marker.x.set(position = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command moves a marker to a specific coordinate on the x-axis. If necessary, the command activates the marker.
		If the marker has been used as a delta marker, the command turns it into a normal marker. \n
			:param position: Numeric value that defines the marker position on the x-axis. The unit depends on the result display. Range: The range depends on the current x-axis range. , Unit: Hz
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(position)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:X {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:X \n
		Snippet: value: float = driver.applications.k60Transient.calculate.marker.x.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command moves a marker to a specific coordinate on the x-axis. If necessary, the command activates the marker.
		If the marker has been used as a delta marker, the command turns it into a normal marker. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: position: Numeric value that defines the marker position on the x-axis. The unit depends on the result display. Range: The range depends on the current x-axis range. , Unit: Hz"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:X?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IconCls:
	"""Icon commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("icon", core, parent)

	def set(self, icon_path: str, icon_index: str) -> None:
		"""SCPI: SYSTem:PLUGin:APPStarter:ICON \n
		Snippet: driver.system.plugin.appStarter.icon.set(icon_path = '1', icon_index = '1') \n
		No command help available \n
			:param icon_path: No help available
			:param icon_index: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('icon_path', icon_path, DataType.String), ArgSingle('icon_index', icon_index, DataType.String))
		self._core.io.write(f'SYSTem:PLUGin:APPStarter:ICON {param}'.rstrip())

	# noinspection PyTypeChecker
	class IconStruct(StructBase):
		"""Response structure. Fields: \n
			- Icon_Path: str: No parameter help available
			- Icon_Index: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Icon_Path'),
			ArgStruct.scalar_str('Icon_Index')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Icon_Path: str = None
			self.Icon_Index: str = None

	def get(self) -> IconStruct:
		"""SCPI: SYSTem:PLUGin:APPStarter:ICON \n
		Snippet: value: IconStruct = driver.system.plugin.appStarter.icon.get() \n
		No command help available \n
			:return: structure: for return value, see the help for IconStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:PLUGin:APPStarter:ICON?', self.__class__.IconStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:CLEar[:IMMediate] \n
		Snippet: driver.calculate.limit.clear.immediate.set(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command deletes the result of the current limit check. The command works on all limit lines in all measurement
		windows at the same time. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CLEar:IMMediate')

	def set_with_opc(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		"""SCPI: CALCulate<n>:LIMit<li>:CLEar[:IMMediate] \n
		Snippet: driver.calculate.limit.clear.immediate.set_with_opc(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command deletes the result of the current limit check. The command works on all limit lines in all measurement
		windows at the same time. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CLEar:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, arg_0: enums.EventOnce, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: CALibration:PMETer<p>:ZERO:AUTO \n
		Snippet: driver.applications.k50Spurious.calibration.pmeter.zero.auto.set(arg_0 = enums.EventOnce.ONCE, powerMeter = repcap.PowerMeter.Default) \n
		This command zeroes the power sensor. Note that you have to disconnect the signals from the power sensor input before you
		start to zero the power sensor. Otherwise, results are invalid. \n
			:param arg_0: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.EventOnce)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'CALibration:PMETer{powerMeter_cmd_val}:ZERO:AUTO {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:CLEar:STATe \n
		Snippet: driver.massMemory.clear.state.set(filename = '1') \n
		This command deletes an instrument configuration file. \n
			:param filename: String containing the path and name of the file to delete. The string may or may not contain the file's extension.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write_with_opc(f'MMEMory:CLEar:STATe 1, {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	@property
	def hcontinuous(self):
		"""hcontinuous commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hcontinuous'):
			from .Hcontinuous import HcontinuousCls
			self._hcontinuous = HcontinuousCls(self._core, self._cmd_group)
		return self._hcontinuous

	def set(self, trace_mode: enums.TraceModeF, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:MODE \n
		Snippet: driver.display.window.subwindow.trace.mode.set(trace_mode = enums.TraceModeF.AVERage, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the trace mode. If necessary, the selected trace is also activated. For max hold, min hold or
		average trace mode, you can set the number of single measurements with [SENSe:]SWEep:COUNt. Note that synchronization to
		the end of the measurement is possible only in single sweep mode. For more information, see 'Analyzing several traces -
		trace mode'. \n
			:param trace_mode: WRITe (default:) Overwrite mode: the trace is overwritten by each sweep. AVERage The average is formed over several sweeps. The 'Sweep/Average Count' determines the number of averaging procedures. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. BLANk Hides the selected trace. WRHold The trace is overwritten when new data is available, but only after all cross-correlation operations defined for a half decade are done.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(trace_mode, enums.TraceModeF)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> enums.TraceModeF:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:MODE \n
		Snippet: value: enums.TraceModeF = driver.display.window.subwindow.trace.mode.get(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		This command selects the trace mode. If necessary, the selected trace is also activated. For max hold, min hold or
		average trace mode, you can set the number of single measurements with [SENSe:]SWEep:COUNt. Note that synchronization to
		the end of the measurement is possible only in single sweep mode. For more information, see 'Analyzing several traces -
		trace mode'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: trace_mode: WRITe (default:) Overwrite mode: the trace is overwritten by each sweep. AVERage The average is formed over several sweeps. The 'Sweep/Average Count' determines the number of averaging procedures. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. BLANk Hides the selected trace. WRHold The trace is overwritten when new data is available, but only after all cross-correlation operations defined for a half decade are done."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TraceModeF)

	def clone(self) -> 'ModeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ModeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScopeCls:
	"""Scope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scope", core, parent)

	def set(self, scope: enums.FramesScope) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SCOPe \n
		Snippet: driver.sense.correction.fresponse.user.scope.set(scope = enums.FramesScope.ALL) \n
		No command help available \n
			:param scope: No help available
		"""
		param = Conversions.enum_scalar_to_str(scope, enums.FramesScope)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:SCOPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FramesScope:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SCOPe \n
		Snippet: value: enums.FramesScope = driver.sense.correction.fresponse.user.scope.get() \n
		No command help available \n
			:return: scope: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:SCOPe?')
		return Conversions.str_to_scalar_enum(response, enums.FramesScope)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, ser_level: float) -> None:
		"""SCPI: [SENSe]:DDEMod:FSYNc:LEVel \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.fsync.level.set(ser_level = 1.0) \n
		This command sets the Fine Sync Level if fine sync works on Known Data \n
			:param ser_level: Range: 0.0 to 100.0, Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(ser_level)
		self._core.io.write(f'SENSe:DDEMod:FSYNc:LEVel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:FSYNc:LEVel \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.fsync.level.get() \n
		This command sets the Fine Sync Level if fine sync works on Known Data \n
			:return: ser_level: Range: 0.0 to 100.0, Unit: PCT"""
		response = self._core.io.query_str(f'SENSe:DDEMod:FSYNc:LEVel?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self) -> None:
		"""SCPI: HCOPy:TREPort:TEST:SELect:ALL \n
		Snippet: driver.hardCopy.treport.test.select.all.set() \n
		No command help available \n
		"""
		self._core.io.write(f'HCOPy:TREPort:TEST:SELect:ALL')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: HCOPy:TREPort:TEST:SELect:ALL \n
		Snippet: driver.hardCopy.treport.test.select.all.set_with_opc() \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'HCOPy:TREPort:TEST:SELect:ALL', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CpresentCls:
	"""Cpresent commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cpresent", core, parent)

	def set(self, state: bool, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:MSR:LTE:CPResent \n
		Snippet: driver.sense.espectrum.msr.lte.cpresent.set(state = False, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param state: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.bool_to_str(state)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:MSR:LTE:CPResent {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> bool:
		"""SCPI: [SENSe]:ESPectrum<sb>:MSR:LTE:CPResent \n
		Snippet: value: bool = driver.sense.espectrum.msr.lte.cpresent.get(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: state: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:MSR:LTE:CPResent?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	def set(self, filter_name: str) -> None:
		"""SCPI: [SENSe]:DDEMod:MFILter:USER \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.mfilter.user.set(filter_name = '1') \n
		This command selects the user-defined measurement filter. For details on user-defined filters, see 'Customized filters'. \n
			:param filter_name: Name of the user-defined filter
		"""
		param = Conversions.value_to_quoted_str(filter_name)
		self._core.io.write(f'SENSe:DDEMod:MFILter:USER {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:MFILter:USER \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.mfilter.user.get() \n
		This command selects the user-defined measurement filter. For details on user-defined filters, see 'Customized filters'. \n
			:return: filter_name: Name of the user-defined filter"""
		response = self._core.io.query_str(f'SENSe:DDEMod:MFILter:USER?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SaveCls:
	"""Save commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("save", core, parent)

	def set(self, filename: str = None) -> None:
		"""SCPI: DIAGnostic:SERVice:SFUNction:RESults:SAVE \n
		Snippet: driver.diagnostic.service.sfunction.results.save.set(filename = '1') \n
		This command saves the results in the output buffer for service functions you have used to a file. If no <FileName>
		parameter is provided, the results are stored to C:/R_S/INSTR/results/Servicelog.txt. Note that if the buffer is empty,
		the function returns an error. \n
			:param filename: String containing the path and file name.
		"""
		param = ''
		if filename:
			param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'DIAGnostic:SERVice:SFUNction:RESults:SAVE {param}'.strip())

	def get(self) -> str:
		"""SCPI: DIAGnostic:SERVice:SFUNction:RESults:SAVE \n
		Snippet: value: str = driver.diagnostic.service.sfunction.results.save.get() \n
		This command saves the results in the output buffer for service functions you have used to a file. If no <FileName>
		parameter is provided, the results are stored to C:/R_S/INSTR/results/Servicelog.txt. Note that if the buffer is empty,
		the function returns an error. \n
			:return: filename: String containing the path and file name."""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:SFUNction:RESults:SAVE?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WselectCls:
	"""Wselect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wselect", core, parent)

	def get(self) -> int:
		"""SCPI: DISPlay:WSELect \n
		Snippet: value: int = driver.display.wselect.get() \n
		This command queries the currently active window (the one that is focused) in the currently selected measurement channel. \n
			:return: selected_window: Index number of the currently active window. Range: 1 to 16"""
		response = self._core.io.query_str(f'DISPlay:WSELect?')
		return Conversions.str_to_int(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> List[float]:
		"""SCPI: CALCulate<n>:SNOise<m>:DECades:X \n
		Snippet: value: List[float] = driver.applications.k40PhaseNoise.calculate.snoise.decades.x.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Snoise')
			:return: frequencies: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_bin_or_ascii_float_list(f'CALCulate{window_cmd_val}:SNOise{marker_cmd_val}:DECades:X?')
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrameCls:
	"""Frame commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frame", core, parent)

	def set(self, frame: float, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:SPECtrogram:FRAMe \n
		Snippet: driver.applications.k60Transient.calculate.deltaMarker.spectrogram.frame.set(frame = 1.0, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command positions a delta marker on a particular frame. The frame is relative to the position of marker 1.
		The command is available for the spectrogram. \n
			:param frame: Selects a frame either by its frame number or time stamp. The frame number is available if the time stamp is off. The range depends on the history depth. The time stamp is available if the time stamp is on. The number is the distance to frame 0 in seconds. The range depends on the history depth. Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.decimal_value_to_str(frame)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:SPECtrogram:FRAMe {param}')

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:SPECtrogram:FRAMe \n
		Snippet: value: float = driver.applications.k60Transient.calculate.deltaMarker.spectrogram.frame.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command positions a delta marker on a particular frame. The frame is relative to the position of marker 1.
		The command is available for the spectrogram. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: frame: Selects a frame either by its frame number or time stamp. The frame number is available if the time stamp is off. The range depends on the history depth. The time stamp is available if the time stamp is on. The number is the distance to frame 0 in seconds. The range depends on the history depth. Unit: S"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:SPECtrogram:FRAMe?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HdepthCls:
	"""Hdepth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hdepth", core, parent)

	def set(self, history: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:SPECtrogram:HDEPth \n
		Snippet: driver.calculate.spectrogram.hdepth.set(history = 1.0, window = repcap.Window.Default) \n
		No command help available \n
			:param history: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(history)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:SPECtrogram:HDEPth {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:SPECtrogram:HDEPth \n
		Snippet: value: float = driver.calculate.spectrogram.hdepth.get(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: history: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:SPECtrogram:HDEPth?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TemperatureCls:
	"""Temperature commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("temperature", core, parent)

	@property
	def control(self):
		"""control commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	def set(self, temperature: float) -> None:
		"""SCPI: [SENSe]:CORRection:TEMPerature \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.temperature.set(temperature = 1.0) \n
		This command defines the room temperature of the measurement environment. The temperature is taken into account when
		calculating noise results. \n
			:param temperature: Range: 278.15 to 318.15, Unit: K
		"""
		param = Conversions.decimal_value_to_str(temperature)
		self._core.io.write(f'SENSe:CORRection:TEMPerature {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:TEMPerature \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.correction.temperature.get() \n
		This command defines the room temperature of the measurement environment. The temperature is taken into account when
		calculating noise results. \n
			:return: temperature: Range: 278.15 to 318.15, Unit: K"""
		response = self._core.io.query_str(f'SENSe:CORRection:TEMPerature?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'TemperatureCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TemperatureCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SetCls:
	"""Set commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("set", core, parent)

	# noinspection PyTypeChecker
	class SetStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Sample_Rate: float: numeric value The frequency at which measurement values are taken from the A/D-converter and stored in I/Q memory. Unit: HZ
			- Record_Length: float: Number of samples to be stored in I/Q memory. Range: 1 to 400001 with AF filter or AF trigger active, 1 to 480001 with both AF filter and AF trigger deactive
			- Trigger_Source: enums.TriggerSourceB: IMMediate | EXTernal | EXT2 | EXT3 | IFPower | RFPower| AF | AM | AMRelative | FM | PM Note: After selecting IF Power, the trigger threshold can be set with the [CMDLINK: TRIGger[:SEQuence]:LEVel:IFPower CMDLINK] command.
			- Trigger_Slope: enums.SlopeType: POSitive | NEGative Used slope of the trigger signal. The value indicated here will be ignored for trigger source = IMMediate.
			- Offset_Samples: float: Number of samples to be used as an offset to the trigger signal. The value indicated here is ignored for trigger source = 'IMMediate'.
			- No_Of_Meas: float: Number of repetitions of the measurement to be executed. The value indicated here is especially necessary for the average/maxhold/minhold function. Range: 0 to 32767"""
		__meta_args_list = [
			ArgStruct.scalar_float('Sample_Rate'),
			ArgStruct.scalar_float('Record_Length'),
			ArgStruct.scalar_enum('Trigger_Source', enums.TriggerSourceB),
			ArgStruct.scalar_enum('Trigger_Slope', enums.SlopeType),
			ArgStruct.scalar_float('Offset_Samples'),
			ArgStruct.scalar_float('No_Of_Meas')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Sample_Rate: float = None
			self.Record_Length: float = None
			self.Trigger_Source: enums.TriggerSourceB = None
			self.Trigger_Slope: enums.SlopeType = None
			self.Offset_Samples: float = None
			self.No_Of_Meas: float = None

	def set(self, structure: SetStruct) -> None:
		"""SCPI: [SENSe]:ADEMod:SET \n
		Snippet with structure: \n
		structure = driver.sense.ademod.set.SetStruct() \n
		structure.Sample_Rate: float = 1.0 \n
		structure.Record_Length: float = 1.0 \n
		structure.Trigger_Source: enums.TriggerSourceB = enums.TriggerSourceB.ACVideo \n
		structure.Trigger_Slope: enums.SlopeType = enums.SlopeType.NEGative \n
		structure.Offset_Samples: float = 1.0 \n
		structure.No_Of_Meas: float = 1.0 \n
		driver.sense.ademod.set.set(structure) \n
		This command configures the analog demodulator of the instrument. \n
			:param structure: for set value, see the help for SetStruct structure arguments.
		"""
		self._core.io.write_struct(f'SENSe:ADEMod:SET', structure)

	def get(self) -> SetStruct:
		"""SCPI: [SENSe]:ADEMod:SET \n
		Snippet: value: SetStruct = driver.sense.ademod.set.get() \n
		This command configures the analog demodulator of the instrument. \n
			:return: structure: for return value, see the help for SetStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:ADEMod:SET?', self.__class__.SetStruct())
